==============
Flask-SSO
==============

.. image:: https://travis-ci.org/inveniosoftware/flask-sso.png?branch=master
    :target: https://travis-ci.org/inveniosoftware/flask-sso
.. image:: https://coveralls.io/repos/inveniosoftware/flask-sso/badge.png?branch=master
    :target: https://coveralls.io/r/inveniosoftware/flask-sso
.. image:: https://pypip.in/v/flask-sso/badge.png
   :target: https://crate.io/packages/flask-sso/
.. image:: https://pypip.in/d/flask-sso/badge.png
   :target: https://crate.io/packages/flask-sso/

Installation
============
Flask-SSO is on PyPI so all you need is: ::

    pip install Flask-SSO

Documentation
============
Documentation is available at <http://flask-sso.readthedocs.org> or can be built using Sphinx: ::

    pip install Sphinx
    python setup.py build_sphinx

Testing
=======
Running the tests are as simple as: ::

    python setup.py test

or (to also show test coverage) ::

    source run-tests.sh

License
=======
Copyright (C) 2014 CERN.

Flask-SSO is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

Flask-SSO is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with Flask-SSO; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

In applying this licence, CERN does not waive the privileges and immunities granted to it by virtue of its status as an Intergovernmental Organization or submit itself to any jurisdiction.

.. image:: https://d2weczhvl823v0.cloudfront.net/inveniosoftware/flask-sso/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free
